Compare commits

..

4 Commits

Author SHA1 Message Date
Robert Hensing
2513e2f1f0 lib.types.attrNamesTo{Set,Submodule}: add 2025-05-16 15:09:31 +02:00
Robert Hensing
e938d5b77a lib/types.nix: Remove duplicate user documentation 2025-05-16 15:09:25 +02:00
Robert Hensing
1980e9a444 lib/tests/modules: Test attrNamesToTrue 2025-05-16 15:09:24 +02:00
Will Fancher
851d4f4f2b lib.types.attrNamesToTrue: add
(cherry picked from commit 98652f9a90)
2025-05-16 12:35:16 +02:00
115 changed files with 1151 additions and 6899 deletions

View File

@@ -25,9 +25,8 @@ For new packages please briefly describe the package or provide a link to its ho
- made sure NixOS tests are [linked](https://github.com/NixOS/nixpkgs/blob/master/pkgs/README.md#linking-nixos-module-tests-to-a-package) to the relevant packages
- [ ] Tested compilation of all packages that depend on this change using `nix-shell -p nixpkgs-review --run "nixpkgs-review rev HEAD"`. Note: all changes have to be committed, also see [nixpkgs-review usage](https://github.com/Mic92/nixpkgs-review#usage)
- [ ] Tested basic functionality of all binary files (usually in `./result/bin/`)
- [Nixpkgs 25.11 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/doc/release-notes/rl-2511.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/doc/manual/release-notes/rl-2505.section.md) Nixpkgs Release notes)
- [25.05 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) Release notes)
- [ ] (Package updates) Added a release notes entry if the change is major or breaking
- [NixOS 25.11 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2511.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) NixOS Release notes)
- [ ] (Module updates) Added a release notes entry if the change is significant
- [ ] (Module addition) Added a release notes entry if adding a new NixOS module
- [ ] Fits [CONTRIBUTING.md](https://github.com/NixOS/nixpkgs/blob/master/CONTRIBUTING.md).

View File

@@ -31,7 +31,7 @@ jobs:
into: staging-next-24.11
- from: staging-next-24.11
into: staging-24.11
- from: release-25.05
- from: master
into: staging-next-25.05
- from: staging-next-25.05
into: staging-25.05

View File

@@ -345,7 +345,7 @@ See [Nix Channel Status](https://status.nixos.org/) for the current channels and
Here's a brief overview of the main Git branches and what channels they're used for:
- `master`: The main branch, used for the unstable channels such as `nixpkgs-unstable`, `nixos-unstable` and `nixos-unstable-small`.
- `release-YY.MM` (e.g. `release-25.11`): The NixOS release branches, used for the stable channels such as `nixos-25.11`, `nixos-25.11-small` and `nixpkgs-25.11-darwin`.
- `release-YY.MM` (e.g. `release-25.05`): The NixOS release branches, used for the stable channels such as `nixos-25.05`, `nixos-25.05-small` and `nixpkgs-25.05-darwin`.
When a channel is updated, a corresponding Git branch is also updated to point to the corresponding commit.
So e.g. the [`nixpkgs-unstable` branch](https://github.com/nixos/nixpkgs/tree/nixpkgs-unstable) corresponds to the Git commit from the [`nixpkgs-unstable` channel](https://channels.nixos.org/nixpkgs-unstable).

View File

@@ -35,21 +35,18 @@ rustPlatform.buildRustPackage (finalAttrs: {
hash = "...";
};
nativeBuildInputs =
[
# Pull in our main hook
cargo-tauri.hook
nativeBuildInputs = [
# Pull in our main hook
cargo-tauri.hook
# Setup npm
nodejs
npmHooks.npmConfigHook
# Setup npm
nodejs
npmHooks.npmConfigHook
# Make sure we can find our libraries
pkg-config
]
++ lib.optionals stdenv.hostPlatform.isLinux [
wrapGAppsHook4
];
# Make sure we can find our libraries
pkg-config
wrapGAppsHook4
];
buildInputs =
[ openssl ]

View File

@@ -3,6 +3,5 @@
This section lists the release notes for each stable version of Nixpkgs and current unstable revision.
```{=include=} sections
rl-2511.section.md
rl-2505.section.md
```

View File

@@ -1,4 +1,4 @@
# Nixpkgs 25.11 ("Xantusia", 2025.11/??) {#sec-nixpkgs-release-25.11}
# Nixpkgs 25.11 (2025.11/??) {#sec-nixpkgs-release-25.11}
## Highlights {#sec-nixpkgs-release-25.11-highlights}
<!-- To avoid merge conflicts, consider adding your item at an arbitrary place in the list instead. -->

View File

@@ -1 +1 @@
25.11
25.05

View File

@@ -160,6 +160,9 @@ checkConfigError 'A definition for option .intStrings\.badTagTypeError\.left. is
checkConfigError 'A definition for option .nested\.right\.left. is not of type .signed integer.' config.nested.right.left ./types-attrTag.nix
checkConfigError 'In attrTag, each tag value must be an option, but tag int was a bare type, not wrapped in mkOption.' config.opt.int ./types-attrTag-wrong-decl.nix
# types.nix assertions
checkConfigOutput '"ok"' config.check ./types.nix
# types.pathInStore
checkConfigOutput '".*/store/0lz9p8xhf89kb1c1kk6jxrzskaiygnlh-bash-5.2-p15.drv"' config.pathInStore.ok1 ./types.nix
checkConfigOutput '".*/store/0fb3ykw9r5hpayd05sr0cizwadzq1d8q-bash-5.2-p15"' config.pathInStore.ok2 ./types.nix

View File

@@ -1,4 +1,4 @@
{ lib, ... }:
{ config, lib, ... }:
let
inherit (builtins)
storeDir
@@ -7,10 +7,24 @@ let
types
mkOption
;
m = {
options = {
enableQux = mkOption {
type = types.bool;
default = false;
};
};
};
in
{
options = {
check = mkOption { };
# NB: types are tested in multiple places, so this list is far from exhaustive
pathInStore = mkOption { type = types.lazyAttrsOf types.pathInStore; };
attrNamesToTrue = mkOption { type = types.lazyAttrsOf types.attrNamesToTrue; };
attrNamesToSet = mkOption { type = types.lazyAttrsOf types.attrNamesToSet; };
attrNamesToSubmodules = mkOption { type = types.lazyAttrsOf (types.attrNamesToSubmodules m); };
};
config = {
pathInStore.ok1 = "${storeDir}/0lz9p8xhf89kb1c1kk6jxrzskaiygnlh-bash-5.2-p15.drv";
@@ -21,5 +35,112 @@ in
pathInStore.bad3 = "${storeDir}/";
pathInStore.bad4 = "${storeDir}/.links"; # technically true, but not reasonable
pathInStore.bad5 = "/foo/bar";
attrNamesToTrue.justNames = [
"a"
"b"
"c"
];
attrNamesToTrue.mixed = lib.mkMerge [
{
a = true;
b = false;
}
[ "c" ]
];
attrNamesToTrue.trivial = {
a = true;
b = false;
c = true;
};
attrNamesToSet.justNames = [
"a"
"b"
"c"
];
attrNamesToSet.mixed = lib.mkMerge [
{
a = { };
b = { };
}
[ "c" ]
];
attrNamesToSet.trivial = {
a = { };
b = { };
c = { };
};
attrNamesToSubmodules.justNames = [
"a"
"b"
"c"
];
attrNamesToSubmodules.mixed = lib.mkMerge [
{
a = { };
b.enableQux = true;
}
[ "c" ]
];
attrNamesToSubmodules.trivial = {
a = { };
b.enableQux = true;
c = { };
};
check =
assert
config.attrNamesToTrue.justNames == {
a = true;
b = true;
c = true;
};
assert
config.attrNamesToTrue.mixed == {
a = true;
b = false;
c = true;
};
assert
config.attrNamesToTrue.trivial == {
a = true;
b = false;
c = true;
};
assert
config.attrNamesToSet.justNames == {
a = { };
b = { };
c = { };
};
assert
config.attrNamesToSet.mixed == {
a = { };
b = { };
c = { };
};
assert
config.attrNamesToSet.trivial == {
a = { };
b = { };
c = { };
};
assert
config.attrNamesToSubmodules.justNames == {
a.enableQux = false;
b.enableQux = false;
c.enableQux = false;
};
assert
config.attrNamesToSubmodules.mixed == {
a.enableQux = false;
b.enableQux = true;
c.enableQux = false;
};
assert
config.attrNamesToSubmodules.trivial == {
a.enableQux = false;
b.enableQux = true;
c.enableQux = false;
};
"ok";
};
}

View File

@@ -439,7 +439,7 @@ in
On each release the first letter is bumped and a new animal is chosen
starting with that new letter.
*/
codeName = "Xantusia";
codeName = "Warbler";
/**
Returns the current nixpkgs version suffix as string.

View File

@@ -1456,6 +1456,23 @@ let
nestedTypes.finalType = finalType;
};
# Tests: lib/tests/modules/types.nix
# Docs: nixos/doc/manual/development/option-types.section.md
# Docs: https://nixos.org/manual/nixos/unstable/#sec-option-types-basic
attrNamesToTrue = coercedTo (types.listOf types.str) (
enabledList: lib.genAttrs enabledList (_attrName: true)
) (types.attrsOf types.bool);
# Tests: lib/tests/modules.sh, lib/tests/modules/types.nix
# Docs: nixos/doc/manual/development/option-types.section.md
# Docs: https://nixos.org/manual/nixos/unstable/#sec-option-types-basic
attrNamesToSet = attrNamesToSubmodules { };
attrNamesToSubmodules =
m:
coercedTo (types.listOf types.str) (enabledList: lib.genAttrs enabledList (_attrName: { })) (
types.attrsOf (types.submodule m)
);
# Augment the given type with an additional type check function.
addCheck = elemType: check: elemType // { check = x: elemType.check x && check x; };

View File

@@ -4811,12 +4811,6 @@
name = "Coca";
keys = [ { fingerprint = "99CB 86FF 62BB 7DA4 8903 B16D 0328 2DF8 8179 AB19"; } ];
};
cococolanosugar = {
name = "George Xu";
github = "cococolanosugar";
githubId = 1736138;
email = "cococolanosugar@gmail.com";
};
coconnor = {
email = "coreyoconnor@gmail.com";
github = "coreyoconnor";
@@ -7298,13 +7292,6 @@
githubId = 428026;
name = "embr";
};
emilia = {
email = "nix@emilia.codes";
github = "emiliaaah";
githubId = 55017867;
name = "Emilia";
keys = [ { fingerprint = "F772 3569 4B43 B599 73C2 A931 1EFB E941 B89B B810"; } ];
};
emilioziniades = {
email = "emilioziniades@protonmail.com";
github = "emilioziniades";
@@ -9195,12 +9182,6 @@
githubId = 1621335;
name = "Andrew Trachenko";
};
goodylove = {
github = "goodylove";
email = "goodyc474@gmail.com";
githubId = 104577296;
name = "Nwachukwu Goodness";
};
gordon-bp = {
email = "gordy@hanakano.com";
github = "Gordon-BP";
@@ -17772,12 +17753,6 @@
githubId = 41154684;
name = "nokazn";
};
nomaterials = {
email = "nomaterials@gmail.com";
github = "no-materials";
githubId = 16938952;
name = "nomaterials";
};
nomeata = {
email = "mail@joachim-breitner.de";
github = "nomeata";
@@ -27315,6 +27290,12 @@
githubId = 5986078;
name = "Zunway Liang";
};
zanculmarktum = {
name = "Azure Zanculmarktum";
email = "zanculmarktum@gmail.com";
github = "zanculmarktum";
githubId = 16958511;
};
zane = {
name = "Zane van Iperen";
email = "zane@zanevaniperen.com";

View File

@@ -869,7 +869,6 @@ with lib.maintainers;
qyriad
_9999years
lf-
alois31
];
scope = "Maintain the Lix package manager inside of Nixpkgs.";
shortName = "Lix ecosystem";
@@ -1120,17 +1119,9 @@ with lib.maintainers;
};
sdl = {
members = [
evythedemon
grimmauld
jansol
marcin-serwin
pbsds
];
githubTeams = [ "SDL" ];
scope = "Maintain core SDL libraries.";
members = [ ];
scope = "Maintain SDL libraries.";
shortName = "SDL";
enableFeatureFreezePing = true;
};
sphinx = {

View File

@@ -135,6 +135,79 @@ merging is handled.
problems.
:::
`types.attrNamesToTrue`
: Either a list of attribute names, or an attribute set of
booleans. A list will be coerced into an attribute set with those
names, whose values are set to `true`. This is useful when it is
convenient to be able to write definitions as a simple list, but
still need to be able to override and disable individual values.
If configurability of the items is needed or `false` is not a
desirable value, prefer `types.attrNamesToSubmodule` or `types.attrNamesToSet`.
::: {#ex-types-attrNamesToTrue .example}
### `types.attrNamesToTrue`
```
{
foo = [ "bar" ];
}
```
```
{
foo.bar = true;
}
```
:::
`types.attrNamesToSet`
: Either a list of attribute names, or an attribute set of `{ }`.
This is similar to `types.attrNamesToTrue`, but `false` is not a permitted
value. This is useful when that's not an expected value, and by using this
type, you have the option to upgrade the type to `types.attrNamesToSubmodule`
without breaking anything.
::: {#ex-types-attrNamesToSet .example}
### `types.attrNamesToSet`
```
{
foo = [ "bar" ];
}
```
```
{
foo.bar = { };
}
```
:::
`types.attrNamesToSubmodule` *`submodule`*
: Either a list of attribute names, or an attribute set of submodules.
This is similar to `types.attrNamesToSet`, but the values are submodules
instead of empty sets. This is useful when the values of this type are
optionally configurable.
::: {#ex-types-attrNamesToSubmodule .example}
### `types.attrNamesToSubmodule`
```
{
foo = [ "bar" ];
}
```
```
{
foo.bar = { };
foo.baz.enableQux = true;
}
```
:::
`types.pkgs`
: A type for the top level Nixpkgs package set.

View File

@@ -1994,9 +1994,6 @@
"sec-release-25.05-notable-changes": [
"release-notes.html#sec-release-25.05-notable-changes"
],
"sec-release-25.05-wiki": [
"release-notes.html#sec-release-25.05-wiki"
],
"sec-nixpkgs-release-25.05": [
"release-notes.html#sec-nixpkgs-release-25.05"
],

View File

@@ -3,7 +3,6 @@
This section lists the release notes for each stable version of NixOS and current unstable revision.
```{=include=} sections
rl-2511.section.md
rl-2505.section.md
rl-2411.section.md
rl-2405.section.md

View File

@@ -646,10 +646,6 @@
<!-- To avoid merge conflicts, consider adding your item at an arbitrary place in the list instead. -->
## NixOS Wiki {#sec-release-25.05-wiki}
The official NixOS Wiki at [wiki.nixos.org](https://wiki.nixos.org) has new and improved articles, new contributors and some improvements in its dark theme and mobile readability.
```{=include=} sections
../release-notes-nixpkgs/rl-2505.section.md
```

View File

@@ -1,4 +1,4 @@
# Release 25.11 ("Xantusia", 2025.11/??) {#sec-release-25.11}
# Release 25.11 (2025.11/??) {#sec-release-25.11}
## Highlights {#sec-release-25.11-highlights}

View File

@@ -45,7 +45,7 @@ let
# To be able to open the firewall, we need to read out port values in the
# server properties, but fall back to the defaults when those don't exist.
# These defaults are from https://minecraft.wiki/w/Server.properties#Java_Edition
# These defaults are from https://minecraft.gamepedia.com/Server.properties#Java_Edition_3
defaultServerPort = 25565;
serverPort = cfg.serverProperties.server-port or defaultServerPort;
@@ -93,8 +93,10 @@ in
type = lib.types.bool;
default = false;
description = ''
Whether you agree to [Mojangs EULA](https://www.minecraft.net/eula).
This option must be set to `true` to run Minecraft server.
Whether you agree to
[
Mojangs EULA](https://account.mojang.com/documents/minecraft_eula). This option must be set to
`true` to run Minecraft server.
'';
};
@@ -165,10 +167,10 @@ in
}
'';
description = ''
Minecraft server properties forthe server.properties file. Only has
Minecraft server properties for the server.properties file. Only has
an effect when {option}`services.minecraft-server.declarative`
is set to `true`. See
<https://minecraft.wiki/w/Server.properties#Java_Edition>
<https://minecraft.gamepedia.com/Server.properties#Java_Edition_3>
for documentation on these values.
'';
};
@@ -180,7 +182,7 @@ in
jvmOpts = lib.mkOption {
type = lib.types.separatedString " ";
default = "-Xmx2048M -Xms2048M";
# Example options from https://minecraft.wiki/w/Tutorial:Server_startup_script
# Example options from https://minecraft.gamepedia.com/Tutorials/Server_startup_script
example =
"-Xms4092M -Xmx4092M -XX:+UseG1GC -XX:+CMSIncrementalPacing "
+ "-XX:+CMSClassUnloadingEnabled -XX:ParallelGCThreads=2 "

View File

@@ -633,7 +633,6 @@ in
in
{
Restart = "always";
RestartSec = "5s";
Type = "simple";
User = cfg.user;
Group = cfg.group;

View File

@@ -41,6 +41,8 @@ let
if [ "$(readlink "$out/etc/$target")" != "$src" ]; then
echo "mismatched duplicate entry $(readlink "$out/etc/$target") <-> $src"
ret=1
continue
fi
fi

View File

@@ -632,7 +632,6 @@ let
grubUseEfi ? false,
enableOCR ? false,
meta ? { },
passthru ? { },
testSpecialisationConfig ? false,
testFlakeSwitch ? false,
testByAttrSwitch ? false,
@@ -645,7 +644,7 @@ let
isEfi = bootLoader == "systemd-boot" || (bootLoader == "grub" && grubUseEfi);
in
makeTest {
inherit enableOCR passthru;
inherit enableOCR;
name = "installer-" + name;
meta = {
# put global maintainers here, individuals go into makeInstallerTest fkt call
@@ -1110,12 +1109,10 @@ in
# The (almost) simplest partitioning scheme: a swap partition and
# one big filesystem partition.
simple = makeInstallerTest "simple" (
simple-test-config
// {
passthru.override = args: makeInstallerTest "simple" simple-test-config // args;
}
);
simple = makeInstallerTest "simple" simple-test-config;
lix-simple = makeInstallerTest "simple" simple-test-config // {
selectNixPackage = pkgs: pkgs.lix;
};
switchToFlake = makeInstallerTest "switch-to-flake" simple-test-config-flake;

View File

@@ -3,17 +3,21 @@
let
inherit (pkgs) lib;
tests.default = testsForPackage { nixPackage = pkgs.nix; };
testsForPackage = args: {
# If the attribute is not named 'test'
# You will break all the universe on the release-*.nix side of things.
# `discoverTests` relies on `test` existence to perform a `callTest`.
test = testMiscFeatures args // {
passthru.override = args': (testsForPackage (args // args')).test;
};
tests = {
default = testsForPackage { nixPackage = pkgs.nix; };
lix = testsForPackage { nixPackage = pkgs.lix; };
};
testsForPackage =
args:
lib.recurseIntoAttrs {
# If the attribute is not named 'test'
# You will break all the universe on the release-*.nix side of things.
# `discoverTests` relies on `test` existence to perform a `callTest`.
test = testMiscFeatures args;
passthru.override = args': testsForPackage (args // args');
};
testMiscFeatures =
{ nixPackage, ... }:
pkgs.testers.nixosTest (

View File

@@ -137,19 +137,6 @@ final: prev: {
meta.hydraPlatforms = [ ];
};
GPTModels-nvim = buildVimPlugin {
pname = "GPTModels.nvim";
version = "2025-05-15";
src = fetchFromGitHub {
owner = "Aaronik";
repo = "GPTModels.nvim";
rev = "04d91c778d74f762143203ab81e155eec642b5f6";
sha256 = "06spvkfc1bhckq8w56w6ha4gzk60wfhjlyivrx51awz20sd6hyw0";
};
meta.homepage = "https://github.com/Aaronik/GPTModels.nvim/";
meta.hydraPlatforms = [ ];
};
Improved-AnsiEsc = buildVimPlugin {
pname = "Improved-AnsiEsc";
version = "2015-08-26";
@@ -8930,12 +8917,12 @@ final: prev: {
neogit = buildVimPlugin {
pname = "neogit";
version = "2025-05-15";
version = "2025-04-16";
src = fetchFromGitHub {
owner = "NeogitOrg";
repo = "neogit";
rev = "6de4b9f9a92917f9aea3a0dbdc3dbbedc11d26be";
sha256 = "0z9qri9sp1aicma1yiy2vkdjixjj7pbprd86nmslrhrnchvnqrbh";
rev = "9bb1e73c534f767607e0a888f3de4c942825c501";
sha256 = "06qcyz3snk8bphbd2n9q4dzizkksn65is0nksd76q0zzkvb9qxhp";
};
meta.homepage = "https://github.com/NeogitOrg/neogit/";
meta.hydraPlatforms = [ ];

View File

@@ -1314,13 +1314,6 @@ in
];
};
GPTModels-nvim = super.GPTModels-nvim.overrideAttrs {
dependencies = with self; [
nui-nvim
telescope-nvim
];
};
guard-collection = super.guard-collection.overrideAttrs {
dependencies = [ self.guard-nvim ];
};

View File

@@ -9,7 +9,6 @@ https://github.com/whonore/Coqtail/,,
https://github.com/vim-scripts/DoxygenToolkit.vim/,,
https://github.com/numToStr/FTerm.nvim/,,
https://github.com/antoinemadec/FixCursorHold.nvim/,,
https://github.com/Aaronik/GPTModels.nvim/,HEAD,
https://github.com/vim-scripts/Improved-AnsiEsc/,,
https://github.com/ionide/Ionide-vim/,HEAD,
https://github.com/martinda/Jenkinsfile-vim-syntax/,,

View File

@@ -27,8 +27,8 @@ let
mktplcRef = {
name = "language-x86-64-assembly";
publisher = "13xforever";
version = "3.1.5";
hash = "sha256-WIhmAZLR2WOSqQF3ozJ/Vr3Rp6HdSK7L23T3h4AVaGM=";
version = "3.1.4";
hash = "sha256-FJRDm1H3GLBfSKBSFgVspCjByy9m+j9OStlU+/pMfs8=";
};
meta = {
description = "Cutting edge x86 and x86_64 assembly syntax highlighting";
@@ -89,8 +89,8 @@ let
mktplcRef = {
publisher = "42Crunch";
name = "vscode-openapi";
version = "4.33.2";
hash = "sha256-agCxi2UhJitdQmHIf6rK7WexkfljUQdqK5rLqzV4J6o=";
version = "4.33.1";
hash = "sha256-iq0UpVaZMOzh4NIRPLk49ciFuO4A6PDSEMe1KKhfSxA=";
};
meta = {
changelog = "https://marketplace.visualstudio.com/items/42Crunch.vscode-openapi/changelog";
@@ -4027,8 +4027,8 @@ let
mktplcRef = {
publisher = "redhat";
name = "java";
version = "1.42.0";
hash = "sha256-m6RJm8eleMjDNy5ixfXWtOcPmsjNynCUNuF9lsCB8ho=";
version = "1.41.2025031208";
hash = "sha256-0VWLkztB7anIs19QN1yPQvVjNim+DICv43IOMwEaM+E=";
};
buildInputs = [ jdk ];
meta = {

View File

@@ -8,8 +8,8 @@ vscode-utils.buildVscodeMarketplaceExtension {
mktplcRef = {
publisher = "RooVeterinaryInc";
name = "roo-cline";
version = "3.17.1";
hash = "sha256-gfzn0KulOHUKcG3LNF7+g7VwkDHR4BYsmq730Uuv2ZU=";
version = "3.16.5";
hash = "sha256-UbOLY1qHYOoMQq3Agm2qI2+I6YLwv2kec6nqPyGZha4=";
};
passthru.updateScript = vscode-extension-update-script { };

View File

@@ -40,11 +40,11 @@
python3.pkgs.buildPythonApplication rec {
pname = "gajim";
version = "2.2.0";
version = "2.1.1";
src = fetchurl {
url = "https://gajim.org/downloads/${lib.versions.majorMinor version}/gajim-${version}.tar.gz";
hash = "sha256-TOZuMiE5RjaJYvNWxl2FyCp6uIO+LLWiRb7N9jc1yRk=";
hash = "sha256-1pPrc7lzxaLK1QbxslGYGS8xOxuT231RvZrdvWeGFOk=";
};
format = "pyproject";

View File

@@ -8,22 +8,22 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "amazon-q-cli";
version = "1.10.0";
version = "1.9.1";
src = fetchFromGitHub {
owner = "aws";
repo = "amazon-q-developer-cli";
tag = "v${finalAttrs.version}";
hash = "sha256-X1L3Nrzchp8yuGGBwwLQ4ZE41GKH3pFR2CX77TYYhNo=";
hash = "sha256-BiVCiMBL5LLm8RYw58u6P7yqQq9XnN8b6fTbxNE2QsA=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-qtQ+e0NRzzGn0s2zpnMNUv7JdQDuImMfyC0C/QZrpjU=";
cargoHash = "sha256-7zUgWLGTZx3Ex7RYxb3eZimWdy6AxkNwpCDUwiAr2JE=";
cargoBuildFlags = [
"-p"
"chat_cli"
"q_cli"
];
nativeBuildInputs = [
@@ -31,12 +31,12 @@ rustPlatform.buildRustPackage (finalAttrs: {
];
postInstall = ''
install -m 0755 $out/bin/chat_cli $out/bin/amazon-q
install -m 0755 $out/bin/q_cli $out/bin/amazon-q
'';
cargoTestFlags = [
"-p"
"chat_cli"
"q_cli"
];
# skip integration tests that have external dependencies
@@ -60,7 +60,6 @@ rustPlatform.buildRustPackage (finalAttrs: {
"--skip=init_lint_zsh_post_zshrc"
"--skip=init_lint_zsh_pre_zprofile"
"--skip=init_lint_zsh_pre_zshrc"
"--skip=telemetry::cognito::test::pools"
];
doInstallCheck = true;

View File

@@ -6,11 +6,11 @@
stdenvNoCC.mkDerivation rec {
pname = "amiri";
version = "1.002";
version = "1.001";
src = fetchzip {
url = "https://github.com/alif-type/amiri/releases/download/${version}/Amiri-${version}.zip";
hash = "sha256-Ln2AFiQ5hX4w1yu5NCF28S0hmfWUhEINi1YJVV/Gngo=";
hash = "sha256-YwiDY5/Ty5Pwj3d8+UafUNLVZ3omRtFRWQCLn2RkheM=";
};
installPhase = ''

View File

@@ -11,11 +11,11 @@
stdenv.mkDerivation rec {
pname = "bird";
version = "3.1.1";
version = "3.0.2";
src = fetchurl {
url = "https://bird.nic.cz/download/bird-${version}.tar.gz";
hash = "sha256-KXJRl0/4g+TvA/zNbJEtEW7Un/Lxxjtm0dul8HCUREo=";
url = "https://bird.network.cz/download/bird-${version}.tar.gz";
hash = "sha256-eKqL5820LfFLnilpu2Q7IoxoBMZXj5CTsXPOiiQ3zDA=";
};
nativeBuildInputs = [
@@ -43,7 +43,7 @@ stdenv.mkDerivation rec {
meta = with lib; {
changelog = "https://gitlab.nic.cz/labs/bird/-/blob/v${version}/NEWS";
description = "BIRD Internet Routing Daemon";
homepage = "https://bird.nic.cz/";
homepage = "https://bird.network.cz";
license = licenses.gpl2Plus;
maintainers = with maintainers; [ herbetom ];
platforms = platforms.linux;

View File

@@ -18,13 +18,13 @@ let
in
stdenv.mkDerivation (finalAttrs: {
pname = "cherry-studio";
version = "1.3.4";
version = "1.3.2";
src = fetchFromGitHub {
owner = "CherryHQ";
repo = "cherry-studio";
tag = "v${finalAttrs.version}";
hash = "sha256-xCS8ZomIAVEnQ2SJRay/ii7xhPMO+ctc8C14Xrje8kI=";
hash = "sha256-Tgd8MvxsiCDp2pdtz2MeCnTGY4Butw9V/UoTw0XEaIg=";
};
postPatch = ''
@@ -41,7 +41,7 @@ stdenv.mkDerivation (finalAttrs: {
offlineCache = yarn-berry.fetchYarnBerryDeps {
inherit (finalAttrs) src missingHashes;
hash = "sha256-cStjxlmOnoDfrt6z5jvpkHfIKyfZ9UFWbbZjnJLiTu4=";
hash = "sha256-WUsG8mqozphU2YIT73KqMNP62TBiay3EiGrMBgd2QJw=";
};
nativeBuildInputs = [
@@ -89,12 +89,7 @@ stdenv.mkDerivation (finalAttrs: {
runHook preInstall
mkdir -p $out/opt/cherry-studio
${
if stdenv.hostPlatform.isAarch64 then
"cp -r dist/linux-arm64-unpacked/{resources,LICENSE*} $out/opt/cherry-studio"
else
"cp -r dist/linux-unpacked/{resources,LICENSE*} $out/opt/cherry-studio"
}
cp -r dist/linux-unpacked/{resources,LICENSE*} $out/opt/cherry-studio
install -Dm644 build/icon.png $out/share/pixmaps/cherry-studio.png
makeWrapper ${lib.getExe electron} $out/bin/cherry-studio \
--inherit-argv0 \

View File

@@ -7,13 +7,13 @@
buildGoModule rec {
pname = "circleci-cli";
version = "0.1.31632";
version = "0.1.31543";
src = fetchFromGitHub {
owner = "CircleCI-Public";
repo = pname;
rev = "v${version}";
sha256 = "sha256-3ufazu7DuUFp3aBxQ5MPlndECHSjvEIscYjlvE3j9G8=";
sha256 = "sha256-0hikYA7oU3tTHZdEcxDzMXCg13+muk6V7MyqJwExm0A=";
};
vendorHash = "sha256-H7q373HL6M6ETkXEY5tAwN32rx0eMkqRAAZ4kQf9rKk=";

View File

@@ -9,13 +9,13 @@
buildGoModule rec {
pname = "cloudflared";
version = "2025.5.0";
version = "2025.4.0";
src = fetchFromGitHub {
owner = "cloudflare";
repo = "cloudflared";
tag = version;
hash = "sha256-ZnkE9x4A9HoiSXzvYuzyW/dH08r0aJUk/q6gFVgtTjk=";
hash = "sha256-PKF7wP/ueLLhV8k3nMUm/c5fkg+7CwRf1oLnx0qbcA0=";
};
vendorHash = null;

View File

@@ -45,11 +45,11 @@ let
in
stdenvNoCC.mkDerivation (finalAttrs: {
pname = "copilot-language-server";
version = "1.322.0";
version = "1.312.0";
src = fetchzip {
url = "https://github.com/github/copilot-language-server-release/releases/download/${finalAttrs.version}/copilot-language-server-native-${finalAttrs.version}.zip";
hash = "sha256-3AJTC4TI+sqTi1/B1XQZght7CClplWwIxjGmrt1E2ME=";
hash = "sha256-glZR72+5lpghItwHuzDZKd/KONsCrjjCwcyNK0k9jr8=";
stripRoot = false;
};

View File

@@ -1,37 +0,0 @@
{
fetchFromGitHub,
lib,
stdenv,
}:
stdenv.mkDerivation {
pname = "finalmouse-udev-rules";
version = "0-unstable-2025-05-05";
src = fetchFromGitHub {
owner = "teamfinalmouse";
repo = "xpanel-linux-permissions";
rev = "60c4ed794bd946e467559cc572cf25bb99bf04b6";
hash = "sha256-E2xhm+8fFlxgIKjZlAvosLk/KgbmLk01BjK++y8laBc=";
};
dontUnpack = true;
installPhase = ''
runHook preInstall
install -Dpm644 $src/99-finalmouse.rules $out/lib/udev/rules.d/70-finalmouse.rules
runHook postInstall
'';
meta = {
homepage = "https://github.com/teamfinalmouse/xpanel-linux-permissions";
description = "udev rules that give NixOS permission to communicate with Finalmouse mice";
platforms = lib.platforms.linux;
license = lib.licenses.mit;
maintainers = with lib.maintainers; [
emilia
];
};
}

View File

@@ -7,14 +7,14 @@
python3Packages.buildPythonApplication rec {
pname = "flexget";
version = "3.15.42";
version = "3.15.38";
pyproject = true;
src = fetchFromGitHub {
owner = "Flexget";
repo = "Flexget";
tag = "v${version}";
hash = "sha256-ON0j5HYNbpHSwTMJgX/xPLjzLZXRDk1YogbhcwugxJE=";
hash = "sha256-quEqpF5oj1FLmQrIS4t3HwS23/m/QH/ZVijlQapt5Mc=";
};
pythonRelaxDeps = true;

File diff suppressed because it is too large Load Diff

View File

@@ -13,7 +13,7 @@
let
pname = "freeplane";
version = "1.12.10";
version = "1.12.8";
jdk = jdk17;
gradle = gradle_8;
@@ -22,7 +22,7 @@ let
owner = "freeplane";
repo = "freeplane";
rev = "release-${version}";
hash = "sha256-08Rl3vhXtlylNDc1gh5aZJ9/RoxeyxpDbklmhMVJuq4=";
hash = "sha256-yzjzaobXuQH8CHz183ditL2LsCXU5xLh4+3El4Ffu20=";
};
in
@@ -37,11 +37,10 @@ stdenvNoCC.mkDerivation (finalAttrs: {
];
patches = [
# freeplane is using the wrong repository for a plugin
# remove when https://github.com/freeplane/freeplane/pull/2453 is merged and released
# Plugin update to support Gradle 8.13; remove when included in a release.
(fetchpatch {
url = "https://github.com/amadejkastelic/freeplane/commit/973c49b7a73622e434bb86c8caea15383201b58a.patch";
hash = "sha256-iztFmISXZu8xKWqpwDYgBSl8ZSpZEtNriwM+EW1+s+Y=";
url = "https://github.com/freeplane/freeplane/commit/e58958783ef6f85ab00bf270c1f897093c4d7006.patch";
hash = "sha256-oQF/GbItl2ZEVlTKzojqk9xTWl8CVP7V3yig/py71hk=";
})
];

View File

@@ -49,14 +49,14 @@ let
in
stdenv.mkDerivation (finalAttrs: {
pname = "gamescope";
version = "3.16.9";
version = "3.16.7";
src = fetchFromGitHub {
owner = "ValveSoftware";
repo = "gamescope";
tag = finalAttrs.version;
fetchSubmodules = true;
hash = "sha256-Dw9EErOINGoOlnNqroKR+fbRfMGL7Q13gP3E5iw4RhU=";
hash = "sha256-q0yTOyu47tQXorFfnmRa4wrt0KRnyelLDmfcg4iwPfs=";
};
patches = [

View File

@@ -1,42 +0,0 @@
{
lib,
buildGoModule,
fetchFromGitHub,
}:
buildGoModule rec {
pname = "goctl";
version = "1.8.3";
src = fetchFromGitHub {
owner = "zeromicro";
repo = "go-zero";
tag = "v${version}";
hash = "sha256-v5WzqMotF9C7i9hTYSjaPmTwveBVDVn+SKQXYuS4Rdc=";
};
vendorHash = "sha256-tOIlfYiAI9m7oTZyPDCzTXg9XTwBb6EOVLzDfZnzL4E=";
modRoot = "tools/goctl";
subPackages = [ "." ];
doCheck = true;
ldflags = [
"-s"
"-w"
];
meta = {
description = "CLI handcuffle of go-zero, a cloud-native Go microservices framework";
longDescription = ''
goctl is a go-zero's built-in handcuffle that is a major
lever to increase development efficiency, generating code,
document, deploying k8s yaml, dockerfile, etc.
'';
homepage = "https://go-zero.dev";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ cococolanosugar ];
mainProgram = "goctl";
};
}

View File

@@ -171,11 +171,11 @@ let
linux = stdenv.mkDerivation (finalAttrs: {
inherit pname meta passthru;
version = "136.0.7103.113";
version = "136.0.7103.59";
src = fetchurl {
url = "https://dl.google.com/linux/chrome/deb/pool/main/g/google-chrome-stable/google-chrome-stable_${finalAttrs.version}-1_amd64.deb";
hash = "sha256-BnKKu7X34g+zg4rDqjVXT3Kx2E8Gn5ELqs3LQS3GCkg=";
hash = "sha256-dki7Ci91OpqMtgS84ynsxBWoB862t+eWFlxHvZUAUjc=";
};
# With strictDeps on, some shebangs were not being patched correctly
@@ -274,11 +274,11 @@ let
darwin = stdenvNoCC.mkDerivation (finalAttrs: {
inherit pname meta passthru;
version = "136.0.7103.114";
version = "136.0.7103.49";
src = fetchurl {
url = "http://dl.google.com/release2/chrome/iwktnyywqpn7dye3zjzgosvevq_136.0.7103.114/GoogleChrome-136.0.7103.114.dmg";
hash = "sha256-myJawlgVBQlLtgBfSfCL5XfdnH8d7xd+j8JV2+2MZ/s=";
url = "http://dl.google.com/release2/chrome/dz4uae22obgiqcnhey5k6wspvu_136.0.7103.49/GoogleChrome-136.0.7103.49.dmg";
hash = "sha256-4eGfwVdts+tW4ouUKZg1EvnSYOu6CCBRMYie2hz2y00=";
};
dontPatch = true;

View File

@@ -59,7 +59,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://www.gnu.org/software/guile-sdl/";
description = "Guile bindings for SDL";
license = lib.licenses.gpl3Plus;
maintainers = [ ];
teams = [ lib.teams.sdl ];
inherit (guile.meta) platforms;
};
})

File diff suppressed because it is too large Load Diff

View File

@@ -1,38 +0,0 @@
{
lib,
buildNpmPackage,
fetchFromGitHub,
nix-update-script,
}:
buildNpmPackage (finalAttrs: {
pname = "hypercore";
version = "11.7.0";
src = fetchFromGitHub {
owner = "holepunchto";
repo = "hypercore";
tag = "v${finalAttrs.version}";
hash = "sha256-ZAKWFSOIAQysK9+4YxbUiL0fVsqnGFqhwe9ps6ZXYv0=";
};
npmDepsHash = "sha256-ZJxVmQWKgHyKkuYfGIlANXFcROjI7fibg6mxIhDZowM=";
dontNpmBuild = true;
postPatch = ''
cp ${./package-lock.json} ./package-lock.json
'';
passthru.updateScript = nix-update-script { };
meta = {
description = "Secure, distributed append-only log";
homepage = "https://github.com/holepunchto/hypercore";
license = lib.licenses.mit;
teams = with lib.teams; [ ngi ];
maintainers = [ lib.maintainers.goodylove ];
platforms = lib.platforms.all;
};
})

View File

@@ -1,8 +1,8 @@
diff --git a/admin/Makefile.def b/admin/Makefile.def
index facc205..0daceaf 100644
index 43ef322..cad3de2 100644
--- a/admin/Makefile.def
+++ b/admin/Makefile.def
@@ -310,7 +310,7 @@ endif
@@ -306,7 +306,7 @@ endif
# Apple CLANG flags (identical to GCC)
ifeq ($(GAG_COMPILER_CKIND),clang)
@@ -11,7 +11,7 @@ index facc205..0daceaf 100644
ifeq ($(RELEASE_MODE),no)
OPTION_CFLAGS += -Wall
endif
@@ -360,7 +360,7 @@ endif
@@ -356,7 +356,7 @@ endif
# GFORTRAN flags
ifeq ($(GAG_COMPILER_FKIND),gfortran)
@@ -21,17 +21,55 @@ index facc205..0daceaf 100644
GLOBAL_FFLAGS += -fsanitize=address -fsanitize=null
# Can not be used with our memory(ip):
diff --git a/admin/define-system.sh b/admin/define-system.sh
index 36d4ab9..0233259 100644
index f68274d..dd1a9be 100644
--- a/admin/define-system.sh
+++ b/admin/define-system.sh
@@ -287,8 +287,8 @@ EOF
fi
@@ -279,35 +279,22 @@ EOF
else
GAG_MACHINE=pc
fi
- if which gcc > /dev/null 2>&1; then
- DEFAULT_CCOMPILER=gcc
- fi
- if which g++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=g++
- elif which clang++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=clang++
- fi
- if which ifort > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=ifort
- elif which gfortran > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=gfortran
- fi
elif [ `uname -p` = "arm" ]; then
defsys_message "WARNING: experimental ARM support"
GAG_MACHINE=arm64
- if which gcc > /dev/null 2>&1; then
- DEFAULT_CCOMPILER=gcc
+ if which clang > /dev/null 2>&1; then
+ DEFAULT_CCOMPILER=clang
fi
if which clang++ > /dev/null 2>&1; then
DEFAULT_CXXCOMPILER=clang++
- fi
- if which g++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=g++
- elif which clang++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=clang++
- fi
- if which ifort > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=ifort
- elif which gfortran > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=gfortran
- fi
+ fi
+ if which clang > /dev/null 2>&1; then
+ DEFAULT_CCOMPILER=clang
+ fi
+ if which clang++ > /dev/null 2>&1; then
+ DEFAULT_CXXCOMPILER=clang++
+ elif which g++ > /dev/null 2>&1; then
+ DEFAULT_CXXCOMPILER=g++
+ fi
+ if which ifort > /dev/null 2>&1; then
+ DEFAULT_FCOMPILER=ifort
+ elif which gfortran > /dev/null 2>&1; then
+ DEFAULT_FCOMPILER=gfortran
fi ;;
CYGWIN*)
if [ `uname -m | grep -c "x86_64"` -ne 0 ]; then

View File

@@ -26,15 +26,15 @@ let
in
stdenv.mkDerivation (finalAttrs: {
version = "4.5-01";
version = "4.4-01";
pname = "imager";
src = fetchurl {
# The recommended download link is on Nextcloud instance that
# requires to accept some general terms of use. Use a mirror at
# univ-grenoble-alpes.fr instead.
url = "https://cloud.univ-grenoble-alpes.fr/s/J6yEqA6yZ8tX9da/download?path=%2F&files=imager-may25.tar.gz";
hash = "sha256-E3JjdVGEQ0I/ogYj0G1OZxfQ3hA+sRgA4LAfHK52Sec=";
url = "https://cloud.univ-grenoble-alpes.fr/s/J6yEqA6yZ8tX9da/download?path=%2F&files=imager-dec24.tar.gz";
hash = "sha256-Pq92IsGY4heekm5zNGngnp6J6YiCHYAyuMT2RsD1/9o=";
};
nativeBuildInputs = [
@@ -55,6 +55,9 @@ stdenv.mkDerivation (finalAttrs: {
];
patches = [
# Update the Python link flag script from Gildas upstream
# version. This patch will be included in the the IMAGER release.
./python-ldflags.patch
# Use Clang as the default compiler on Darwin.
./clang.patch
# Replace hardcoded cpp with GAG_CPP (see below).

View File

@@ -0,0 +1,104 @@
diff --git a/app/main/src-tauri/tauri.conf.json b/app/main/src-tauri/tauri.conf.json
index 1114b19..c4cc8f4 100644
--- a/app/main/src-tauri/tauri.conf.json
+++ b/app/main/src-tauri/tauri.conf.json
@@ -23,7 +23,6 @@
"macOS": {
"frameworks": [],
"exceptionDomain": "",
- "signingIdentity": "-",
"providerShortName": null,
"entitlements": null
},

View File

@@ -16,19 +16,19 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "ruff";
version = "0.11.10";
version = "0.11.9";
src = fetchFromGitHub {
owner = "astral-sh";
repo = "ruff";
tag = finalAttrs.version;
hash = "sha256-8psRFBhOzcFYYOU1aLf2tQwSZeWyn3TjUtfMR8HJ4FE=";
hash = "sha256-TJHBaru0L2pMdZ9omtJ+OqGP764fSwoP54xndWVV6ls=";
};
cargoBuildFlags = [ "--package=ruff" ];
useFetchCargoVendor = true;
cargoHash = "sha256-KwTqm345bRwn5PXn/bTakiBNNjJCIstkXGpqtyCiK4k=";
cargoHash = "sha256-/xIQ8JJI2WfX3rxLZQCwsN2ylURqi+SjkBvnn0Hdij0=";
nativeBuildInputs = [ installShellFiles ];

View File

@@ -73,8 +73,5 @@ rustPlatform.buildRustPackage rec {
platforms = [ "x86_64-linux" ];
maintainers = with maintainers; [ gaelreyrol ];
mainProgram = "scaphandre";
# Upstream needs to decide what to do about a broken dependency
# https://github.com/hubblo-org/scaphandre/issues/403
broken = true;
};
}

View File

@@ -0,0 +1,13 @@
--- a/attacher.c 2025-02-24 20:15:31.701820351 +0100
+++ b/attacher.c 2025-02-24 20:17:05.893826559 +0100
@@ -461,8 +461,8 @@
size_t len;
len = strlen(*av) + 1;
if (p + len >= m.m.command.cmd + ARRAY_SIZE(m.m.command.cmd) - 1)
- break;
+ Panic(0, "Total length of the command to send too large.\n");
- strncpy(p, *av, MAXPATHLEN);
+ memcpy(p, *av, len);
p += len;
}
*p = 0;

View File

@@ -10,11 +10,11 @@
stdenv.mkDerivation rec {
pname = "screen";
version = "5.0.1";
version = "5.0.0";
src = fetchurl {
url = "mirror://gnu/screen/screen-${version}.tar.gz";
hash = "sha256-La429Ns3n/zRS2kVlrpuwYrDqeIrxHrCOXiatYQJhp0=";
hash = "sha256-8Eo50AoOXHyGpVM4gIkDCCrV301z3xov00JZdq7ZSXE=";
};
configureFlags = [
@@ -25,6 +25,13 @@ stdenv.mkDerivation rec {
# We need _GNU_SOURCE so that mallocmock_reset() is defined: https://savannah.gnu.org/bugs/?66416
NIX_CFLAGS_COMPILE = "-D_GNU_SOURCE=1 -Wno-int-conversion -Wno-incompatible-pointer-types";
patches = [
# GNU Screen 5.0 uses strncpy incorrectly in SendCmdMessage
# This causes issues detected when using -D_FORTIFY_SOURCE=3
# e.g. https://savannah.gnu.org/bugs/index.php?66215
./buffer-overflow-SendCmdMessage.patch
];
nativeBuildInputs = [
autoreconfHook
];

View File

@@ -48,7 +48,6 @@ stdenv.mkDerivation rec {
mainProgram = "playsound";
platforms = platforms.unix;
license = licenses.zlib;
teams = [ lib.teams.sdl ];
homepage = "https://www.icculus.org/SDL_sound/";
};
}

View File

@@ -32,7 +32,7 @@ stdenv.mkDerivation {
description = "SDL 1.2 patched with libsixel support";
license = lib.licenses.lgpl21;
mainProgram = "sdl-config";
maintainers = [ ];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.linux;
};
}

View File

@@ -30,7 +30,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://sdl-stretch.sourceforge.net/";
description = "Stretch Functions For SDL";
license = lib.licenses.lgpl2;
maintainers = [ ];
teams = [ lib.teams.sdl ];
inherit (SDL.meta) platforms;
};
})

View File

@@ -103,8 +103,9 @@ stdenv.mkDerivation (finalAttrs: {
license = lib.licenses.zlib;
maintainers = with lib.maintainers; [
nadiaholmquist
grimmauld
marcin-serwin
];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.all;
pkgConfigModules = [
"sdl2-compat"

View File

@@ -79,7 +79,6 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://github.com/libsdl-org/SDL_image";
license = lib.licenses.zlib;
maintainers = [ lib.maintainers.evythedemon ];
teams = [ lib.teams.sdl ];
inherit (sdl3.meta) platforms;
};
})

View File

@@ -62,7 +62,6 @@ stdenv.mkDerivation (finalAttrs: {
charain
Emin017
];
teams = [ lib.teams.sdl ];
pkgConfigModules = [ "sdl3-ttf" ];
platforms = lib.platforms.all;
};

View File

@@ -226,7 +226,6 @@ stdenv.mkDerivation (finalAttrs: {
changelog = "https://github.com/libsdl-org/SDL/releases/tag/${finalAttrs.src.tag}";
license = lib.licenses.zlib;
maintainers = with lib.maintainers; [ getchoo ];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.unix ++ lib.platforms.windows;
pkgConfigModules = [ "sdl3" ];
};

View File

@@ -8,14 +8,14 @@
python3Packages.buildPythonApplication rec {
pname = "snowflake-cli";
version = "3.7.2";
version = "3.7.1";
pyproject = true;
src = fetchFromGitHub {
owner = "snowflakedb";
repo = "snowflake-cli";
tag = "v${version}";
hash = "sha256-MCJl6Mkkkp9JkG+8ZNfWAYQFMJccdtKfPdcnfaY8Y3w=";
hash = "sha256-UhxjyXG2FQFhzhGjnmWSZr1LiW2/RHFvIAbvJP0I7oc=";
};
build-system = with python3Packages; [

View File

@@ -7,7 +7,7 @@
makeWrapper,
}:
let
version = "4.1.7";
version = "4.1.6";
inherit (stdenv.hostPlatform) system;
throwSystem = throw "tailwindcss has not been packaged for ${system} yet.";
@@ -22,10 +22,10 @@ let
hash =
{
aarch64-darwin = "sha256-CjzOBmhnEW0c+V6utNKPROhAOx1ql2vG8S4G1hT6Wdo=";
aarch64-linux = "sha256-jEGaZiGW8FcmVRrQBr2DQfR7i+344MtlFofZrjwK4GY=";
x86_64-darwin = "sha256-TN7TKW561j9qvgadL/P/cQhhum1lCrsjNglhxgz9GSw=";
x86_64-linux = "sha256-BwYpKTWpdzxsh54X0jYlMi5EkOfo96CtDmiPquTe+YE=";
aarch64-darwin = "sha256-vy5DrFSVROGpP4uvS32PtfSBWJbF/vpzE9L0/drOxLc=";
aarch64-linux = "sha256-BPkJ72DfdGdV9ajPO61hoNkhzCfmzZRt1A/sSKcbAok=";
x86_64-darwin = "sha256-PteOE9PWEtn7BNoVT/nw6tz4H5jBFyzOZmZGDxfaGVE=";
x86_64-linux = "sha256-BuaYnp+lBuNbzl3MMVo9xm2n+WJzQ3tb8UsPhgAhRlM=";
}
.${system} or throwSystem;
in

View File

@@ -10,17 +10,17 @@
rustPlatform.buildRustPackage rec {
pname = "tbtools";
version = "0.6.0";
version = "0.5.0";
src = fetchFromGitHub {
owner = "intel";
repo = "tbtools";
tag = "v${version}";
hash = "sha256-xLMnB8KliwHVU5y4L7K0a43gfdhLKFxnAx4wxGL9xMc=";
hash = "sha256-zq8q3JaoqWAQUat2gIW0Wimi/tZiC6XDphUVjH0viU4=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-QuiDI2/XzhUKF7BGnoKeJ2143keJtmi+8WG1MpulLZo=";
cargoHash = "sha256-SAHIDjELm4qr4whoQVdt3EuNA72qFqXEg3H0hYr7yLc=";
nativeBuildInputs = [
pkg-config

View File

@@ -12,15 +12,15 @@
buildPackages,
}:
stdenv.mkDerivation (finalAttrs: {
stdenv.mkDerivation rec {
pname = "telescope";
version = "0.11";
version = "0.10.1";
src = fetchFromGitHub {
owner = "omar-polo";
repo = "telescope";
tag = finalAttrs.version;
hash = "sha256-GKeUXa4RKYkoywrCrpenfLt10Rdj9L0xYI3tf2hFAbk=";
rev = version;
hash = "sha256-MVZ/pvDAETacQiEMEXM0gYM20LXqNiHtMfFGqS1vipY=";
};
postPatch = ''
@@ -45,11 +45,11 @@ stdenv.mkDerivation (finalAttrs: {
"HOSTCC=${buildPackages.stdenv.cc}/bin/${buildPackages.stdenv.cc.targetPrefix}cc"
];
meta = {
meta = with lib; {
description = "Telescope is a w3m-like browser for Gemini";
homepage = "https://telescope-browser.org/";
license = lib.licenses.isc;
maintainers = with lib.maintainers; [ heph2 ];
platforms = lib.platforms.unix;
homepage = "https://www.telescope-browser.org/";
license = licenses.isc;
maintainers = with maintainers; [ heph2 ];
platforms = platforms.unix;
};
})
}

View File

@@ -12,16 +12,16 @@
buildGoModule rec {
pname = "trayscale";
version = "0.16.0";
version = "0.14.3";
src = fetchFromGitHub {
owner = "DeedleFake";
repo = "trayscale";
tag = "v${version}";
hash = "sha256-Fvp75DaU/ZB4VZsUIgiSAg9eWU2JO6aGGwEYaC+VzIE=";
hash = "sha256-HIx3icecgu29jlrHpXfIXzJAxgKSgpeGexouiL2lYB8=";
};
vendorHash = "sha256-KC2eWO3pS8Xbq9FwWfT3bAodhxdTOzpvkBxzxPa9pUY=";
vendorHash = "sha256-hFUzFjQ8LWOKifDp3FiIUwdttX0FrPpRdtWj6fqE5uQ=";
subPackages = [ "cmd/trayscale" ];

View File

@@ -7,16 +7,16 @@
}:
buildGoModule rec {
pname = "treefmt";
version = "2.3.0";
version = "2.2.1";
src = fetchFromGitHub {
owner = "numtide";
repo = "treefmt";
rev = "v${version}";
hash = "sha256-tDezwRWEfPz+u/i9Wz7MZULMmmIUwnl+5gcFU+dDj6Y=";
hash = "sha256-gNGDqCRPvXjbfDQkEP8UsEStL9fsvUVYWPv3d8o1Bq0=";
};
vendorHash = "sha256-9yAvqz99YlBfFU/hGs1PB/sH0iOyWaVadqGhfXMkj5E=";
vendorHash = "sha256-47yOjk3eO5K0T01GUDvheJxoAJz0ZmiV2RdqTv01pYQ=";
subPackages = [ "." ];

View File

@@ -1,35 +0,0 @@
{
fetchFromGitHub,
lib,
nix-update-script,
rustPlatform,
versionCheckHook,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "tuistash";
version = "0.7.1";
src = fetchFromGitHub {
owner = "edmocosta";
repo = "tuistash";
tag = "v${finalAttrs.version}";
hash = "sha256-LWmH/xHvdiY6lC7gsRh2gX31b9Fh4fWekrVdQ++8moQ=";
};
cargoHash = "sha256-mLtzdWHC7HN+hju71WQQZ4nJDMzybEfjzckbfeu32Qo=";
doInstallCheck = true;
nativeInstallCheckInputs = [ versionCheckHook ];
passthru.updateScript = nix-update-script { };
meta = {
description = "Terminal User Interface for Logstash";
homepage = "https://github.com/edmocosta/tuistash";
changelog = "https://github.com/edmocosta/tuistash/blob/v${finalAttrs.version}/CHANGELOG.md";
license = [ lib.licenses.asl20 ];
maintainers = [ lib.maintainers.kpbaks ];
mainProgram = "tuistash";
};
})

View File

@@ -20,17 +20,17 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "uv";
version = "0.7.4";
version = "0.7.3";
src = fetchFromGitHub {
owner = "astral-sh";
repo = "uv";
tag = finalAttrs.version;
hash = "sha256-Lj+qznkYIO7tu12Db2k6hzfh02Ph+Nj6n6j7ncTbPXE=";
hash = "sha256-8yQnBAAzt6kjg1F1AVdLX4z4at8+vCA4lcSclkzXXGw=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-awKbKDyU8r7pdPlce0a0mLavrfnvMssyf/VDD6LRm7Q=";
cargoHash = "sha256-kPJrVHFJcw3tHvLm0ddn4iBoBNK1MDDF0WNcqFfmA4o=";
buildInputs = [
rust-jemalloc-sys
@@ -83,10 +83,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
asl20
mit
];
maintainers = with lib.maintainers; [
GaetanLepage
prince213
];
maintainers = with lib.maintainers; [ GaetanLepage ];
mainProgram = "uv";
};
})

View File

@@ -1,28 +0,0 @@
{
lib,
fetchFromGitea,
rustPlatform,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "uwu-colors";
version = "0.4.0";
src = fetchFromGitea {
domain = "codeberg.org";
owner = "q60";
repo = "uwu_colors";
tag = finalAttrs.version;
hash = "sha256-qzqfLTww0m1rv/7oJZrHMk63CtOk4RzY+Owx0oqlVzI=";
};
cargoHash = "sha256-R/IZUFr8Cir34c+C7Kq6FTFEERiInGMF8yFcC0uQ7Us=";
meta = {
description = "Simple LSP server made to display colors via textDocument/documentColor";
mainProgram = "uwu_colors";
homepage = "https://codeberg.org/q60/uwu_colors";
license = lib.licenses.unlicense;
maintainers = with lib.maintainers; [ vel ];
};
})

View File

@@ -1,74 +0,0 @@
{
lib,
stdenv,
fetchFromGitLab,
eigen,
hidapi,
libopus,
libpulseaudio,
portaudio,
qt6,
qt6Packages,
rtaudio,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "wfview";
version = "2.10";
src = fetchFromGitLab {
owner = "eliggett";
repo = "wfview";
rev = "v${finalAttrs.version}";
hash = "sha256-bFTblsDtFAakbSJfSfKgvoxd1DTSv++rxU6R3/uWo+4=";
};
patches = [
# Remove syscalls during build to make it reproducible
# We also need to adjust some header paths for darwin
./remove-hard-encodings.patch
];
buildInputs =
[
eigen
hidapi
libopus
portaudio
rtaudio
qt6.qtbase
qt6.qtserialport
qt6.qtmultimedia
qt6.qtwebsockets
qt6Packages.qcustomplot
]
++ lib.optionals stdenv.hostPlatform.isLinux [
libpulseaudio
];
nativeBuildInputs = with qt6; [
wrapQtAppsHook
qmake
];
env.LANG = "C.UTF-8";
qmakeFlags = [ "wfview.pro" ];
postInstall = lib.optionalString stdenv.hostPlatform.isDarwin ''
mkdir -pv $out/Applications
mv -v "$out/bin/wfview.app" $out/Applications
# wrap executable to $out/bin
makeWrapper "$out/Applications/wfview.app/Contents/MacOS/wfview" "$out/bin/wfview"
'';
meta = {
description = "Open-source software for the control of modern Icom radios";
homepage = "https://wfview.org/";
license = lib.licenses.gpl3Only;
platforms = lib.platforms.unix;
mainProgram = "wfview";
maintainers = with lib.maintainers; [ Cryolitia ];
};
})

View File

@@ -1,171 +0,0 @@
diff --git a/audioconverter.h b/audioconverter.h
index d3cf510..308725d 100644
--- a/audioconverter.h
+++ b/audioconverter.h
@@ -20,13 +20,8 @@
#endif
/* Opus and Eigen */
-#ifndef Q_OS_LINUX
-#include "opus.h"
-#include <Eigen/Eigen>
-#else
#include "opus/opus.h"
#include <eigen3/Eigen/Eigen>
-#endif
#include "wfviewtypes.h"
diff --git a/audiodevices.h b/audiodevices.h
index 3521eb5..0569e49 100644
--- a/audiodevices.h
+++ b/audiodevices.h
@@ -13,11 +13,7 @@
#include <QFontMetrics>
#include <portaudio.h>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#include "wfviewtypes.h"
diff --git a/rthandler.h b/rthandler.h
index b422cc2..02b1117 100644
--- a/rthandler.h
+++ b/rthandler.h
@@ -6,11 +6,7 @@
#include <QThread>
#include <QMutex>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#include <QAudioFormat>
diff --git a/tciserver.h b/tciserver.h
index 9b38886..af56763 100644
--- a/tciserver.h
+++ b/tciserver.h
@@ -9,13 +9,8 @@
#include "cachingqueue.h"
/* Opus and Eigen */
-#ifndef Q_OS_LINUX
-#include "opus.h"
-#include <Eigen/Eigen>
-#else
#include "opus/opus.h"
#include <eigen3/Eigen/Eigen>
-#endif
#define TCI_AUDIO_LENGTH 4096
struct tciCommandStruct
diff --git a/wfmain.h b/wfmain.h
index 0404fda..e400a74 100644
--- a/wfmain.h
+++ b/wfmain.h
@@ -68,11 +68,7 @@
#include <memory>
#include <portaudio.h>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#ifdef USB_CONTROLLER
#ifdef Q_OS_WIN
diff --git a/wfview.pro b/wfview.pro
index a0943bd..e8f97e1 100644
--- a/wfview.pro
+++ b/wfview.pro
@@ -62,10 +62,8 @@ win32:DEFINES += __WINDOWS_WASAPI__
#linux:DEFINES += __LINUX_OSS__
linux:DEFINES += __LINUX_PULSE__
macx:DEFINES += __MACOSX_CORE__
-!linux:SOURCES += ../rtaudio/RTAudio.cpp
-!linux:HEADERS += ../rtaudio/RTAUdio.h
-!linux:INCLUDEPATH += ../rtaudio
+macx:LIBS += -lrtaudio
linux:LIBS += -lpulse -lpulse-simple -lrtaudio -lpthread -ludev
win32:INCLUDEPATH += ../portaudio/include
@@ -107,8 +105,6 @@ win32:RC_ICONS = "resources/icons/Windows/wfview 512x512.ico"
macx{
ICON = resources/wfview.icns
- QMAKE_MACOSX_DEPLOYMENT_TARGET = 10.15
- QMAKE_APPLE_DEVICE_ARCHS = x86_64 arm64
MY_ENTITLEMENTS.name = CODE_SIGN_ENTITLEMENTS
MY_ENTITLEMENTS.value = resources/wfview.entitlements
QMAKE_MAC_XCODE_SETTINGS += MY_ENTITLEMENTS
@@ -120,8 +116,7 @@ macx{
QMAKE_TARGET_BUNDLE_PREFIX = org.wfview
-!win32:DEFINES += HOST=\\\"`hostname`\\\" UNAME=\\\"`whoami`\\\"
-!win32:DEFINES += GITSHORT="\\\"$(shell git -C \"$$PWD\" rev-parse --short HEAD)\\\""
+!win32:DEFINES += HOST=\\\"nixos\\\" UNAME=\\\"nix\\\" GITSHORT=\\\"0.0\\\"
win32:DEFINES += GITSHORT=\\\"$$system(git -C $$PWD rev-parse --short HEAD)\\\"
win32:DEFINES += HOST=\\\"$$system(hostname)\\\"
@@ -169,19 +164,8 @@ macx:LIBS += -framework CoreAudio -framework CoreFoundation -lpthread -lopus
CONFIG(debug, release|debug) {
- macos:LIBS += -L ../qcustomplot/qcustomplot-sharedlib/build -lqcustomplotd
-
- lessThan(QT_MAJOR_VERSION, 6) {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotd.so/ {print \"-lQCustomPlotd\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd2.so/ {print \"-lqcustomplotd2\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd.so/ {print \"-lqcustomplotd\"}'")
-
- } else {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotdQt6.so/ {print \"-lQCustomPlotdQt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd2qt6.so/ {print \"-lqcustomplotd2qt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotdqt6.so/ {print \"-lqcustomplotdqt6\"}'")
- }
-
+ macos:LIBS += -lqcustomplotd
+ linux:LIBS += -lqcustomplotd
win32 {
contains(QMAKE_TARGET.arch, x86_64) {
LIBS += -L../opus/win32/VS2015/x64/DebugDLL/
@@ -211,17 +195,8 @@ CONFIG(debug, release|debug) {
}
} else {
- macos:LIBS += -L ../qcustomplot/qcustomplot-sharedlib/build -lqcustomplot
-
- lessThan(QT_MAJOR_VERSION, 6) {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlot.so/ {print \"-lQCustomPlot\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot2.so/ {print \"-lqcustomplot2\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot.so/ {print \"-lqcustomplot\"}'")
- } else {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotQt6.so/ {print \"-lQCustomPlotQt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot2qt6.so/ {print \"-lqcustomplot2qt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotqt6.so/ {print \"-lqcustomplotqt6\"}'")
- }
+ macos:LIBS += -lqcustomplot
+ linux:LIBS += -lqcustomplot
win32 {
contains(QMAKE_TARGET.arch, x86_64) {
LIBS += -L../opus/win32/VS2015/x64/ReleaseDLL/
@@ -264,9 +239,6 @@ win32:LIBS += -lopus -lole32 -luser32
#macx:HEADERS += ../qcustomplot/qcustomplot.h
win32:INCLUDEPATH += ../qcustomplot
-!linux:INCLUDEPATH += ../opus/include
-!linux:INCLUDEPATH += ../eigen
-!linux:INCLUDEPATH += ../r8brain-free-src
INCLUDEPATH += resampler

View File

@@ -1,20 +1,20 @@
{
"aarch64-darwin": {
"version": "1.9.0",
"version": "1.8.2",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/darwin-arm64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-darwin-arm64-1.9.0.zip",
"sha256": "44706f90321bdc4c2a2320a03c79fdd01c911236daa4cc675c597851974a268c"
"url": "https://windsurf-stable.codeiumdata.com/darwin-arm64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-darwin-arm64-1.8.2.zip",
"sha256": "d1d353f6f78b570500546a1a1ee140d195df7497ce3eb946fb159afd0cc34a67"
},
"x86_64-darwin": {
"version": "1.9.0",
"version": "1.8.2",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/darwin-x64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-darwin-x64-1.9.0.zip",
"sha256": "ae398d597cd143144c2bdc8bf0a853a1c57b6de2c86c95087a4be5db78252e75"
"url": "https://windsurf-stable.codeiumdata.com/darwin-x64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-darwin-x64-1.8.2.zip",
"sha256": "920ea85cdb98755eeadabf69fa2ed56baf24df7273aa28a1ad7b33f2d4acb862"
},
"x86_64-linux": {
"version": "1.9.0",
"version": "1.8.2",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/linux-x64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-linux-x64-1.9.0.tar.gz",
"sha256": "941640e3514a5ee524943135b439219243adb288fec484712ebc2935173aa938"
"url": "https://windsurf-stable.codeiumdata.com/linux-x64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-linux-x64-1.8.2.tar.gz",
"sha256": "677793a06575428d95e1ad73a0063580f116c9467c100ca0b218b6a89262ba2b"
}
}

View File

@@ -1,23 +0,0 @@
{
lib,
fetchFromGitHub,
mkYaziPlugin,
}:
mkYaziPlugin {
pname = "nord.yazi";
version = "0-unstable-2025-05-14";
src = fetchFromGitHub {
owner = "stepbrobd";
repo = "nord.yazi";
rev = "0f8eff4367021be1b741391d98853fbd1a34baf9";
hash = "sha256-bcYIbKFU1bvGRS6lgEBMe2jT13bECYgQATuh3QKmhQE=";
};
meta = {
description = "nordic yazi";
homepage = "https://github.com/stepbrobd/nord.yazi";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ stepbrobd ];
};
}

View File

@@ -5,13 +5,13 @@
}:
mkYaziPlugin {
pname = "restore.yazi";
version = "25.2.7-unstable-2025-04-24";
version = "25.2.7-unstable-2025-04-04";
src = fetchFromGitHub {
owner = "boydaihungst";
repo = "restore.yazi";
rev = "539aad5077dc8b342a580036e416f2b949b6590e";
hash = "sha256-ngwbweKF7pSEpzy1TNzbKz8cFIWaDison5vCiGxkHFk=";
rev = "328dd888c1e2b9b0cb5dc806f099e3164e179620";
hash = "sha256-3Z8P25u9bffdjrPjxLRWUQn6MdBS+vyElUBkgV4EUwY=";
};
meta = {

View File

@@ -9,13 +9,13 @@
# https://gitlab.com/ente76/guillotine/-/issues/17
stdenv.mkDerivation (finalAttrs: {
pname = "gnome-shell-extension-guillotine";
version = "26";
version = "25";
src = fetchFromGitLab {
owner = "ente76";
repo = "guillotine";
rev = "v${finalAttrs.version}";
hash = "sha256-6RuHargk7sq6oUKj+aGPFp3t0LJCpj6RwLhNzAM5wVA=";
hash = "sha256-HEk1owolLIea4kymoVVeviZ1Ms0kSuHWUda+u+uIh0A=";
};
nativeBuildInputs = [ glib ];

View File

@@ -3230,9 +3230,6 @@ self: super:
# 2025-04-19: Tests randomly fail 5 out of 10 times
fft = dontCheck super.fft;
# 2025-5-15: Too strict bounds on base <4.19, see: https://github.com/zachjs/sv2v/issues/317
sv2v = doJailbreak super.sv2v;
}
// import ./configuration-tensorflow.nix { inherit pkgs haskellLib; } self super

View File

@@ -5935,6 +5935,7 @@ broken-packages:
- supplemented # failure in job https://hydra.nixos.org/build/233237397 at 2023-09-02
- supply-chain-core # failure in job https://hydra.nixos.org/build/252715612 at 2024-03-16
- surjective # failure in job https://hydra.nixos.org/build/233242908 at 2023-09-02
- sv2v # failure in job https://hydra.nixos.org/build/295097359 at 2025-04-22
- sv-core # failure in job https://hydra.nixos.org/build/233217245 at 2023-09-02
- SVD2HS # failure in job https://hydra.nixos.org/build/233248575 at 2023-09-02
- svfactor # failure in job https://hydra.nixos.org/build/233256743 at 2023-09-02

View File

@@ -642669,7 +642669,9 @@ self: {
];
description = "SystemVerilog to Verilog conversion";
license = lib.licenses.bsd3;
hydraPlatforms = lib.platforms.none;
mainProgram = "sv2v";
broken = true;
}
) { };

View File

@@ -1,68 +0,0 @@
{
stdenv,
lib,
fetchFromGitLab,
fetchurl,
fixDarwinDylibNames,
qtbase,
qmake,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "qcustomplot";
version = "2.1.1";
srcs = [
(fetchFromGitLab {
owner = "ecme2";
repo = "QCustomPlot";
tag = "v${finalAttrs.version}";
hash = "sha256-BW8H/vDbhK3b8t8oB92icEBemzcdRdrIz2aKqlUi6UU=";
})
(fetchurl {
url = "https://www.qcustomplot.com/release/${finalAttrs.version}/QCustomPlot-source.tar.gz";
hash = "sha256-Xi0i3sd5248B81fL2yXlT7z5ca2u516ujXrSRESHGC8=";
})
];
sourceRoot = ".";
buildInputs = [ qtbase ];
nativeBuildInputs =
[
qmake
]
++ lib.optionals stdenv.hostPlatform.isDarwin [
fixDarwinDylibNames
];
env.LANG = "C.UTF-8";
qmakeFlags = [ "sharedlib/sharedlib-compilation/sharedlib-compilation.pro" ];
dontWrapQtApps = true;
postUnpack = ''
cp -rv source/* .
cp -rv qcustomplot-source/* .
'';
installPhase = ''
runHook preInstall
install -vDm 644 "qcustomplot.h" -t "$out/include/"
install -vdm 755 "$out/lib/"
cp -av libqcustomplot*${stdenv.hostPlatform.extensions.sharedLibrary}* "$out/lib/"
runHook postInstall
'';
meta = {
homepage = "https://qtcustomplot.com/";
description = "Qt C++ widget for plotting and data visualization";
license = lib.licenses.gpl3Plus;
platforms = lib.platforms.unix;
maintainers = with lib.maintainers; [ Cryolitia ];
};
})

View File

@@ -359,7 +359,7 @@
buildPythonPackage rec {
pname = "boto3-stubs";
version = "1.38.16";
version = "1.38.13";
pyproject = true;
disabled = pythonOlder "3.7";
@@ -367,7 +367,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "boto3_stubs";
inherit version;
hash = "sha256-dZrhWJtN5u/rT0ehuEtObj536bNbT0bpqDTEmpEbfwQ=";
hash = "sha256-j3OnRXRdXtOiBkJ/9GroLEjDf4bQ0mQ5WJi98OVWNSA=";
};
build-system = [ setuptools ];

View File

@@ -10,7 +10,7 @@
buildPythonPackage rec {
pname = "botocore-stubs";
version = "1.38.16";
version = "1.38.13";
pyproject = true;
disabled = pythonOlder "3.7";
@@ -18,7 +18,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "botocore_stubs";
inherit version;
hash = "sha256-SOxutsOJI9Dg+UlOcshpRiq1/9NXi5HNLZH9lNNh4Dw=";
hash = "sha256-x2bLqukcE3oc5RYGAfTMIzEuvWCece16Pbz2qJazs1A=";
};
nativeBuildInputs = [ setuptools ];

View File

@@ -9,14 +9,14 @@
buildPythonPackage rec {
pname = "django-pglock";
version = "1.7.2";
version = "1.7.1";
pyproject = true;
src = fetchFromGitHub {
owner = "AmbitionEng";
repo = "django-pglock";
tag = version;
hash = "sha256-FKAIftHNpfGzED0nkrLv3gVhfS7lyqfwZ1mEKsw/Vc8=";
hash = "sha256-WbifapA2A0grxePozwDSPzREIzmgBV+V5wpA9jeYfJ8=";
};
build-system = [ poetry-core ];
@@ -31,7 +31,7 @@ buildPythonPackage rec {
meta = {
description = "Postgres advisory locks, table locks, and blocking lock management";
homepage = "https://github.com/AmbitionEng/django-pglock";
changelog = "https://github.com/AmbitionEng/django-pglock/blob/${src.tag}/CHANGELOG.md";
changelog = "https://github.com/AmbitionEng/django-pglock/blob/${version}/CHANGELOG.md";
license = lib.licenses.bsd3;
maintainers = with lib.maintainers; [ jopejoe1 ];
};

Some files were not shown because too many files have changed in this diff Show More
diff --git a/admin/python-config-ldflags.py b/admin/python-config-ldflags.py
index 0854698..f397a7c 100644
--- a/admin/python-config-ldflags.py
+++ b/admin/python-config-ldflags.py
@@ -1,38 +1,70 @@
-#!/usr/bin/env python
+# This scripts retrieves the proper options to be used to link against
+# the libpython, in a machine-independant way. It invokes the official
+# script python-config (which thankfully deals with all the details).
-# DUPLICATE of "python-config --ldflags", fixed for the library location
+import sys
+newerpython = (sys.version_info[0] == 3 and sys.version_info[1] > 7)
-# This utility is known to work with:
-# python2.6 (system install) under SL6.4
-# python2.7 (custom install) under SL6.4
-# python3.4 (custom install) under SL6.4
-# python2.7 (system install) under Fedora20
-# python2.7 (Apple install) under MacOSX
-# python2.7 (MacPorts install) under MacOSX
-# python3.4 (MacPorts install) under MacOSX
+if newerpython:
+ # From now on avoid duplicating python-config, which evolves on its own.
+ # Invoke 'python-config --ldflags --embed'. The embed option (under
+ # Python 3) adds the libpython itself, whose name is highly
+ # unpredictible under the variety of machines and configurations we
+ # support
+ import subprocess
+ output = subprocess.check_output(['python-config', '--ldflags','--embed'])
+ output = output.decode('utf-8')
+ #print(output)
-import sys
-import sysconfig
+ args = output.split()
-pyver = sysconfig.get_config_var('VERSION')
-getvar = sysconfig.get_config_var
+ output = ''
+ for arg in args:
+ # Discard /usr/lib* path which causes troubles on the link command
+ # line, as it basically overrides all other custom paths coming after
+ # it. No need to put these paths on command line, they are found
+ # implicitly by the linker.
+ if arg not in ['-L/usr/lib','-L/usr/lib32','-L/usr/lib64']:
+ output += arg+' '
+
+ print(output)
-libs = getvar('LIBS').split() + getvar('SYSLIBS').split()
-if (hasattr(sys,'abiflags')):
- libs.append('-lpython' + pyver + sys.abiflags)
else:
- libs.append('-lpython' + pyver)
+ # DUPLICATE of "python-config --ldflags", fixed for the library location
+ # This proved to work gracefully up to Python 3.5 (exact limit unclear)
+
+ # This utility is known to work with:
+ # python2.6 (system install) under SL6.4
+ # python2.7 (custom install) under SL6.4
+ # python3.4 (custom install) under SL6.4
+ # python3.7 (custom install) under Debian12
+ # python2.7 (system install) under Fedora20
+ # python2.7 (Apple install) under MacOSX
+ # python2.7 (MacPorts install) under MacOSX
+ # python3.4 (MacPorts install) under MacOSX
+
+ import sys
+ import sysconfig
+
+ pyver = sysconfig.get_config_var('VERSION')
+ getvar = sysconfig.get_config_var
+
+ libs = getvar('LIBS').split() + getvar('SYSLIBS').split()
+ if (hasattr(sys,'abiflags')):
+ libs.append('-lpython' + pyver + sys.abiflags)
+ else:
+ libs.append('-lpython' + pyver)
-# Add the library path, except /usr/lib* which causes troubles
-# on the link command line, as it basically overrides all other
-# custom paths coming after it. No need to put these paths on
-# command line, they are found implicitly by the linker.
-ldpath = getvar('LIBDIR')
-if ldpath not in ['/usr/lib','/usr/lib32','/usr/lib64']:
- libs.insert(0, '-L' + getvar('LIBDIR'))
+ # Add the library path, except /usr/lib* which causes troubles
+ # on the link command line, as it basically overrides all other
+ # custom paths coming after it. No need to put these paths on
+ # command line, they are found implicitly by the linker.
+ ldpath = getvar('LIBDIR')
+ if ldpath not in ['/usr/lib','/usr/lib32','/usr/lib64']:
+ libs.insert(0, '-L' + getvar('LIBDIR'))
-# Framework (specific for Mac)
-if not getvar('PYTHONFRAMEWORK'):
- libs.extend(getvar('LINKFORSHARED').split())
+ # Framework (specific for Mac)
+ if not getvar('PYTHONFRAMEWORK'):
+ libs.extend(getvar('LINKFORSHARED').split())
-print(' '.join(libs))
+ print(' '.join(libs))

View File

@@ -31,7 +31,6 @@
perl,
pixman,
vips,
buildPackages,
sourcesJSON ? ./sources.json,
}:
let
@@ -39,62 +38,6 @@ let
sources = lib.importJSON sourcesJSON;
inherit (sources) version;
esbuild_0_23 = buildPackages.esbuild.override {
buildGoModule =
args:
buildPackages.buildGoModule (
args
// rec {
version = "0.23.0";
src = fetchFromGitHub {
owner = "evanw";
repo = "esbuild";
tag = "v${version}";
hash = "sha256-AH4Y5ELPicAdJZY5CBf2byOxTzOyQFRh4XoqRUQiAQw=";
};
vendorHash = "sha256-+BfxCyg0KkDQpHt/wycy/8CTG6YBA/VJvJFhhzUnSiQ=";
}
);
};
esbuild_0_25 = buildPackages.esbuild.override {
buildGoModule =
args:
buildPackages.buildGoModule (
args
// rec {
version = "0.25.2";
src = fetchFromGitHub {
owner = "evanw";
repo = "esbuild";
tag = "v${version}";
hash = "sha256-aDxheDMeQYqCT9XO3In6RbmzmXVchn+bjgf3nL3VE4I=";
};
vendorHash = "sha256-+BfxCyg0KkDQpHt/wycy/8CTG6YBA/VJvJFhhzUnSiQ=";
}
);
};
# Immich server does not actually need esbuild, but react-email and vite do.
# As esbuild doesn't support passing multiple binaries, we use a custom
# "shim", that picks the right version depending on the working directory.
# The correct version can be looked up in package-lock.json
# TODO: There are numerous other env vars this *could* be based on.
esbuildShim = buildPackages.writeShellScriptBin "esbuild" ''
echo "nixpkgs: esbuild shim for '$PWD'" >&2
case "$PWD" in
"/build/server/node_modules/esbuild")
exec ${lib.getExe esbuild_0_23} "$@"
;;
"/build/server/node_modules/vite/node_modules/esbuild")
exec ${lib.getExe esbuild_0_25} "$@"
exit 0
;;
esac
echo "nixpkgs: Couldn't resolve esbuild version for '$PWD'" >&2
exit 1
'';
buildLock = {
sources =
builtins.map
@@ -263,7 +206,6 @@ buildNpmPackage' {
makeCacheWritable = true;
env.SHARP_FORCE_GLOBAL_LIBVIPS = 1;
env.ESBUILD_BINARY_PATH = lib.getExe esbuildShim;
preBuild = ''
# If exiftool-vendored.pl isn't found, exiftool is searched for on the PATH

View File

@@ -1,15 +1,15 @@
{
"version": "3.3.12",
"version": "3.2.13",
"x86_64-linux": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12.AppImage",
"sha256": "1fjrblmlpm6sf4jdvifmyxic0rw2bs1f4sbw3nz4xy7wlsab5f62"
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13.AppImage",
"sha256": "06xmm2annf3i8qfi8hclac3lgfssb2f3sx06vgabgsn67i8gid20"
},
"x86_64-darwin": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12.dmg",
"sha256": "0rk5jl7i7sj31336r8yn8wf9h4xwdwi66wvwrkblvxrfhgddn2gj"
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13.dmg",
"sha256": "1z9lp07z85jf1g2rwzn4q5kssfqqb921lfqgkjkjnz12padf3kpf"
},
"aarch64-darwin": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12-arm64.dmg",
"sha256": "13m4nypg1v5d7i13has9f1sp08dijc44962dr75b9jfiq8q6ciz6"
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13-arm64.dmg",
"sha256": "0r7rfka60vrynwxdfk71mbhdwxv2rivxqc2qpzrhmz26h8vksm3h"
}
}

View File

@@ -9,11 +9,11 @@
stdenvNoCC.mkDerivation rec {
pname = "komga";
version = "1.21.3";
version = "1.21.2";
src = fetchurl {
url = "https://github.com/gotson/${pname}/releases/download/${version}/${pname}-${version}.jar";
sha256 = "sha256-NFj/C1oNRh9PzAi5TUv+4vVea1Nsn/frxf4aZjuYfvA=";
sha256 = "sha256-FYw519VT40PU3fVEb7DBoST2bqhPXcEqquHkGeULQ3k=";
};
nativeBuildInputs = [

View File

@@ -8,12 +8,12 @@
python3Packages.buildPythonApplication rec {
pname = "latexminted";
version = "0.6.0";
version = "0.5.1";
pyproject = true;
src = fetchPypi {
inherit pname version;
hash = "sha256-WpYo9Ci3rshuVdsbAv4Hjx8vT2FLRinhNsVrcGoPXyU=";
hash = "sha256-II3n7DtgTyuE2PMygJrmRW8uBRpnnoz2NXDMw20o8oo=";
};
build-system = with python3Packages; [

View File

@@ -174,11 +174,11 @@ in
stdenv.mkDerivation (finalAttrs: {
pname = "microsoft-edge";
version = "136.0.3240.76";
version = "135.0.3179.85";
src = fetchurl {
url = "https://packages.microsoft.com/repos/edge/pool/main/m/microsoft-edge-stable/microsoft-edge-stable_${finalAttrs.version}-1_amd64.deb";
hash = "sha256-biNM1exJ/xUcmhZjH7ZcFF9cYVqsPavbbtsJnRVlyFo=";
hash = "sha256-x1YpKsvj2Jx1/VE13eE/aCkv+b7rGOQo4xcRYu2GQGA=";
};
# With strictDeps on, some shebangs were not being patched correctly
@@ -284,6 +284,7 @@ stdenv.mkDerivation (finalAttrs: {
license = lib.licenses.unfree;
mainProgram = "microsoft-edge";
maintainers = with lib.maintainers; [
zanculmarktum
kuwii
rhysmdnz
];

View File

@@ -1,43 +0,0 @@
{
lib,
rustPlatform,
fetchCrate,
pkg-config,
openssl,
versionCheckHook,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "mini-redis";
version = "0.4.1";
src = fetchCrate {
inherit (finalAttrs) pname version;
sha256 = "sha256-vYphaQNMAHajod5oT/T3VJ12e6Qk5QOa5LQz6KsXvm8=";
};
cargoHash = "sha256-oGyJxNzJX7PwMkDoT9Tb3xF0vWgQwuyIjKPgEkbPKyI=";
nativeBuildInputs = [
pkg-config
];
buildInputs = [
openssl
];
nativeInstallCheckInputs = [
versionCheckHook
];
doInstallCheck = true;
versionCheckProgram = "${placeholder "out"}/bin/${finalAttrs.meta.mainProgram}";
doCheck = false;
meta = {
description = "Incomplete, idiomatic implementation of a Redis client and server built with Tokio, for learning purposes";
homepage = "https://github.com/tokio-rs/mini-redis";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ nomaterials ];
mainProgram = "mini-redis-cli";
};
})

View File

@@ -11,13 +11,13 @@
stdenv.mkDerivation (finalAttrs: {
pname = "msolve";
version = "0.8.0";
version = "0.7.5";
src = fetchFromGitHub {
owner = "algebraic-solving";
repo = "msolve";
tag = "v${finalAttrs.version}";
hash = "sha256-0kqRnBJA5CwsLY/YWZXu2+y4aiZAQQYl30Qb3JX3zEo=";
hash = "sha256-3AP3qrFZX2JZveONtmG0CLpdwSCwlrW86D8QLRTW5kI=";
};
postPatch = ''

View File

@@ -6,16 +6,16 @@
buildGoModule (finalAttrs: {
pname = "opencode";
version = "0.0.46";
version = "0.0.34";
src = fetchFromGitHub {
owner = "opencode-ai";
repo = "opencode";
tag = "v${finalAttrs.version}";
hash = "sha256-Q7ArUsFMpe0zayUMBJd+fC1K4jTGElIFep31Qa/L1jY=";
hash = "sha256-EaspkL0TEBJEUU3f75EhZ4BOIvbneUKnTNeNGhJdjYE=";
};
vendorHash = "sha256-MVpluFTF/2S6tRQQAXE3ujskQZ3njBkfve0RQgk3IkQ=";
vendorHash = "sha256-cFzkMunPkGQDFhQ4NQZixc5z7JCGNI7eXBn826rWEvk=";
checkFlags =
let

View File

@@ -7,13 +7,13 @@
buildGoModule rec {
pname = "orchard";
version = "0.33.2";
version = "0.33.0";
src = fetchFromGitHub {
owner = "cirruslabs";
repo = pname;
rev = version;
hash = "sha256-yiCMnP73C5MJLYjnZfqcKtdSzPyL/9WlAtylMXDl4E8=";
hash = "sha256-cOg7wwcwmpDNqnu15j5aYxLNpBxrhliK6w3sw2JQlCg=";
# populate values that require us to use git. By doing this in postFetch we
# can delete .git afterwards and maintain better reproducibility of the src.
leaveDotGit = true;
@@ -24,7 +24,7 @@ buildGoModule rec {
'';
};
vendorHash = "sha256-fU2TXUtcXmjswlEbSsbCTOaC5rvtctHbTKbR7zIwP/g=";
vendorHash = "sha256-60GjN9jeYjGdkVxm+lNBS0OYt523c/HrfBPrvdET0hQ=";
nativeBuildInputs = [ installShellFiles ];

View File

@@ -11,13 +11,13 @@
stdenv.mkDerivation (finalAttrs: {
pname = "paho.mqtt.cpp";
version = "1.5.3";
version = "1.5.2";
src = fetchFromGitHub {
owner = "eclipse";
repo = "paho.mqtt.cpp";
tag = "v${finalAttrs.version}";
hash = "sha256-vwfWcJqAWY4Em4MxZVcvOi6pzXAYYlOrKh6peMtjcXo=";
hash = "sha256-3fUqtYFerjEmwn68rNvDeqGU+gly6fkWOyBPikhoFNg=";
};
nativeBuildInputs = [ cmake ];

View File

@@ -10,16 +10,16 @@
buildNpmPackage rec {
pname = "pocket-casts";
version = "0.10.3";
version = "0.10.2";
src = fetchFromGitHub {
owner = "felicianotech";
repo = "pocket-casts-desktop-app";
rev = "v${version}";
hash = "sha256-IhH5nZ2kXVW2D8cMmVyMX4xZLnzfMAp2gwQgZgHOItY=";
hash = "sha256-qXwLnAp8GxOBnPy5uM/Y4dKlALRLo9Hs2p8/WSJcAyE=";
};
npmDepsHash = "sha256-oLZ81SA+eO20sUc2cwba3cc6vu1Qf/lNkIfzK2CQdrw=";
npmDepsHash = "sha256-HU+jfp+Rmw78wTSA0m9Q6EW6+bw84+MEnnSaPnKqqIo=";
env.ELECTRON_SKIP_BINARY_DOWNLOAD = "1";

View File

@@ -7,16 +7,16 @@
buildGoModule rec {
pname = "pocketbase";
version = "0.28.1";
version = "0.27.2";
src = fetchFromGitHub {
owner = "pocketbase";
repo = "pocketbase";
rev = "v${version}";
hash = "sha256-tx9dx4ZFmdllG/pMoI8mmPSvMg7fBk6+lXSxkW5jlDM=";
hash = "sha256-KvKBx5AKpcvgdf8tq2sJPLF63Fpa9KN3j5WJumR28k4=";
};
vendorHash = "sha256-DN3rCuRBFVeRfiXrwxeHemqOZgXb7OswwzcEqHbi4lo=";
vendorHash = "sha256-1Qym5XRyMBfn5csp+YFkKNhJokDrHbfnpKAMq09Da5s=";
# This is the released subpackage from upstream repo
subPackages = [ "examples/base" ];

View File

@@ -10,17 +10,17 @@
rustPlatform.buildRustPackage rec {
pname = "proto";
version = "0.49.1";
version = "0.48.1";
src = fetchFromGitHub {
owner = "moonrepo";
repo = "proto";
rev = "v${version}";
hash = "sha256-VtU59YvNqpHvZ1WRj87Heo8RDyCOzleB+odE4DOQYag=";
hash = "sha256-4ikjpr1IRULLpWC8sseWuF20YXUuCfdCP6VU/VgGWzE=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-wPB4YBNzDg9eoVCY4bbbvKu171Qdh7JJZIT9rD5hVdI=";
cargoHash = "sha256-aa4fL33B4kAZx7A6XRvwLlUHsyZve5WOZBnGCWtfqFU=";
buildInputs = lib.optionals stdenv.hostPlatform.isDarwin [
libiconv

View File

@@ -72,6 +72,7 @@ rustPlatform.buildRustPackage {
];
maintainers = with lib.maintainers; [
detroyejr
uncenter
];
};
}

View File

@@ -8,11 +8,11 @@
stdenv.mkDerivation (finalAttrs: {
pname = "quarkus-cli";
version = "3.22.2";
version = "3.21.4";
src = fetchurl {
url = "https://github.com/quarkusio/quarkus/releases/download/${finalAttrs.version}/quarkus-cli-${finalAttrs.version}.tar.gz";
hash = "sha256-RCWkaPoE3Purq9VG1xhlakMxqXhnxi+q10YcgOyScqg=";
hash = "sha256-ksI55x1rmpIRfNNgajmAvprKU3OwL4EW8QpNV2eyPTc=";
};
nativeBuildInputs = [ makeWrapper ];

View File

@@ -16,7 +16,7 @@
stdenv,
}:
let
version = "2.51.1534";
version = "2.49.1525";
urlVersion = builtins.replaceStrings [ "." ] [ "0" ] version;
in
stdenv.mkDerivation {
@@ -25,7 +25,7 @@ stdenv.mkDerivation {
src = fetchurl {
url = "https://download.roonlabs.com/updates/production/RoonServer_linuxx64_${urlVersion}.tar.bz2";
hash = "sha256-x9zbWJ4lrqfC1CPquGsdgzhO3WBzd46dlZy6APqJbcg=";
hash = "sha256-DYxybP7luRmR4HL6QYBeWU4ZWqlHEO2EgLeqxmFD87A=";
};
dontConfigure = true;

View File

@@ -69,45 +69,37 @@ rustPlatform.buildRustPackage rec {
useFetchCargoVendor = true;
cargoRoot = "app/${app-type}/src-tauri";
buildAndTestSubdir = cargoRoot;
cargoPatches = [
./remove-duplicate-versions-of-sys-metrics.patch
./remove-code-signing-darwin.patch
];
cargoPatches = [ ./remove-duplicate-versions-of-sys-metrics.patch ];
cargoHash = app-type-either "sha256-XfN+/oC3lttDquLfoyJWBaFfdjW/wyODCIiZZksypLM=" "sha256-4vBHxuKg4P9H0FZYYNUT+AVj4Qvz99q7Bhd7x47UC2w=";
nativeBuildInputs =
[
proper-cargo-tauri.hook
nativeBuildInputs = [
proper-cargo-tauri.hook
# Setup pnpm
nodejs
pnpm_9.configHook
# Setup pnpm
nodejs
pnpm_9.configHook
# Make sure we can find our libraries
perl
pkg-config
protobuf
]
++ lib.optionals stdenv.hostPlatform.isLinux [
wrapGAppsHook4
];
# Make sure we can find our libraries
perl
pkg-config
protobuf
wrapGAppsHook4
];
buildInputs =
[ openssl ]
++ lib.optionals stdenv.hostPlatform.isLinux (
[
glib-networking
libayatana-appindicator
]
++ lib.optionals (app-type == "main") [
webkitgtk_4_1
libsoup_3
]
++ lib.optionals (app-type == "legacy") [
webkitgtk_4_0
libsoup_2_4
]
);
++ lib.optionals stdenv.hostPlatform.isLinux [
glib-networking
libayatana-appindicator
]
++ lib.optionals (app-type == "main") [
webkitgtk_4_1
libsoup_3
]
++ lib.optionals (app-type == "legacy") [
webkitgtk_4_0
libsoup_2_4
];
passthru =
# Don't set an update script for the legacy version

View File

@@ -1,12 +0,0 @@